## Shortcut Stories and PRs

<!--- Please fill out the relevant story -->

- Story: [ticket number](link to ticket)
- Relevant Pull Request: [PR link](link to PR in this repo or other)

## Summary

<!--- What did you do? -->

